@@ -22,8 +22,8 @@ fluid = {
 
 # Define suction and discharge states:
 
-suc0 = ccp.State.define(fluid=fluid, p=ps, T=Ts)
-disch0 = ccp.State.define(fluid=fluid, p=Q_(7.255, 'bar'), T=391.1)
+suc0 = ccp.State(fluid=fluid, p=ps, T=Ts)
+disch0 = ccp.State(fluid=fluid, p=Q_(7.255, 'bar'), T=391.1)
 
 # Create performance point(s):
 
@@ -82,7 +82,7 @@ _library_path = _path / _shared_library
 if not _library_path.is_file():
     _warnings.warn(f"{_library_path}.\nREFPROP not configured.")
 
-__version__ = "0.1.23"
+__version__ = "0.2.0"
 
 __version__full = (
     f"ccp: {__version__} | "
