@@ -8,6 +8,8 @@ from ccp.state import State
 from ccp.config.units import check_units
 from ccp import Q_
 import numpy as np
+from scipy.optimize import newton
+from copy import deepcopy
 
 
 class Point1Sec(Point):
@@ -47,7 +49,7 @@ class Point1Sec(Point):
     ...     speed=Q_(7894, "RPM"),
     ...     b=Q_(28.5, "mm"),
     ...     D=Q_(365, "mm"),
-    ...     suc=State.define(
+    ...     suc=State(
     ...         p=Q_(1.826, "bar"),
     ...         T=Q_(296.7, "degK"),
     ...         fluid={
@@ -57,7 +59,7 @@ class Point1Sec(Point):
     ...             "oxygen": 0.0003,
     ...         },
     ...     ),
-    ...     disch=State.define(
+    ...     disch=State(
     ...         p=Q_(6.142, "bar"),
     ...         T=Q_(392.1, "degK"),
     ...         fluid={
@@ -117,12 +119,15 @@ class StraightThrough(Impeller):
     """Straight Through compressor"""
 
     @check_units
-    def __init__(self, guarantee_point, test_points, speed=None):
+    def __init__(
+        self, guarantee_point, test_points, speed=None, reynolds_correction=False
+    ):
         self.guarantee_point = guarantee_point
         self.test_points = test_points
         if speed is None:
             speed = guarantee_point.speed
         self.speed = speed
+        self.reynolds_correction = reynolds_correction
 
         # points for test flange conditions
         self.points_flange_t = test_points
@@ -150,7 +155,7 @@ class StraightThrough(Impeller):
             point.Ts1r = Ts1r
             k_end = k_seal(flow_m=mend, state_up=point.disch, state_down=point.suc)
             self.k_end_seal.append(k_end)
-            suc_rotor = State.define(
+            suc_rotor = State(
                 p=point.suc.p(), T=point.Ts1r, fluid=point.suc.fluid
             )
             test_points_rotor.append(
@@ -186,6 +191,7 @@ class StraightThrough(Impeller):
                     suc=initial_suc,
                     speed=self.speed,
                     find="volume_ratio",
+                    reynolds_correction=self.reynolds_correction,
                 )
                 ms1r_sp = initial_point_rotor_sp.flow_m
                 mend_sp = flow_m_seal(
@@ -219,8 +225,30 @@ class StraightThrough(Impeller):
 
         super().__init__(self.points_flange_sp)
 
+    def calculate_speed_to_match_discharge_pressure(self):
+        """Calculate the speed to match the discharge pressure of the guarantee point."""
 
-class Point2Sec(Point):
+        def calculate_disch_pressure_delta(x):
+            compressor = StraightThrough(
+                guarantee_point=self.guarantee_point,
+                test_points=self.test_points,
+                speed=x,
+                reynolds_correction=self.reynolds_correction,
+            )
+
+            point = compressor.point(flow_m=self.guarantee_point.flow_m, speed=x)
+            return point.disch.p().m - self.guarantee_point.disch.p().m
+
+        new_speed = newton(calculate_disch_pressure_delta, self.speed.m)
+        self.__init__(
+            guarantee_point=self.guarantee_point,
+            test_points=self.test_points,
+            speed=new_speed,
+            reynolds_correction=self.reynolds_correction,
+        )
+
+
+class PointFirstSection(Point):
     """Point class for a compressor with 2 sections in a back-to-back configuration.
 
     Parameters
@@ -264,19 +292,19 @@ class Point2Sec(Point):
     Examples
     --------
     >>> import ccp
-    >>> p = Point2Sec(
+    >>> p = PointFirstSection(
     ...     flow_m=Q_(4.325, "kg/s"),
     ...     speed=Q_(9096, "RPM"),
     ...     b=Q_(10.5, "mm"),
     ...     D=Q_(365, "mm"),
-    ...     suc=State.define(
+    ...     suc=State(
     ...         p=Q_(5.182, "bar"),
     ...         T=Q_(299.5, "degK"),
     ...         fluid={
     ...             "carbon dioxide": 1,
     ...         },
     ...     ),
-    ...     disch=State.define(
+    ...     disch=State(
     ...         p=Q_(14.95, "bar"),
     ...         T=Q_(397.6, "degK"),
     ...         fluid={
@@ -329,6 +357,8 @@ class Point2Sec(Point):
             *args,
             **kwargs,
         )
+        self._args = args
+        self._kwargs = kwargs
         self.balance_line_flow_m = balance_line_flow_m
         self.seal_gas_flow_m = seal_gas_flow_m
         self.seal_gas_temperature = seal_gas_temperature
@@ -345,7 +375,7 @@ class Point2Sec(Point):
         self.oil_outlet_temperature_de = oil_outlet_temperature_de
         self.oil_outlet_temperature_nde = oil_outlet_temperature_nde
 
-        self.end_seal_upstream_state = State.define(
+        self.end_seal_upstream_state = State(
             p=self.end_seal_upstream_pressure,
             T=self.end_seal_upstream_temperature,
             fluid=self.suc.fluid,
@@ -355,7 +385,7 @@ class Point2Sec(Point):
             p=self.end_seal_downstream_state.p(), h=self.end_seal_upstream_state.h()
         )
 
-        self.div_wall_upstream_state = State.define(
+        self.div_wall_upstream_state = State(
             p=self.div_wall_upstream_pressure,
             T=self.div_wall_upstream_temperature,
             fluid=self.suc.fluid,
@@ -365,6 +395,33 @@ class Point2Sec(Point):
             p=self.div_wall_downstream_state.p(), h=self.div_wall_upstream_state.h()
         )
 
+    def __deepcopy__(self, memo):
+        return self.__class__(
+            *self._args,
+            **self._kwargs,
+            balance_line_flow_m=self.balance_line_flow_m,
+            seal_gas_flow_m=self.seal_gas_flow_m,
+            seal_gas_temperature=self.seal_gas_temperature,
+            first_section_discharge_flow_m=self.first_section_discharge_flow_m,
+            div_wall_flow_m=self.div_wall_flow_m,
+            end_seal_upstream_temperature=self.end_seal_upstream_temperature,
+            end_seal_upstream_pressure=self.end_seal_upstream_pressure,
+            div_wall_upstream_temperature=self.div_wall_upstream_temperature,
+            div_wall_upstream_pressure=self.div_wall_upstream_pressure,
+            oil_flow_journal_bearing_de=self.oil_flow_journal_bearing_de,
+            oil_flow_journal_bearing_nde=self.oil_flow_journal_bearing_nde,
+            oil_flow_thrust_bearing_nde=self.oil_flow_thrust_bearing_nde,
+            oil_inlet_temperature=self.oil_inlet_temperature,
+            oil_outlet_temperature_de=self.oil_outlet_temperature_de,
+            oil_outlet_temperature_nde=self.oil_outlet_temperature_nde,
+        )
+
+
+class PointSecondSection(Point1Sec):
+    """Point for second section"""
+
+    pass
+
 
 class BackToBack(Impeller):
     """Back to Back compressor"""
@@ -376,15 +433,23 @@ class BackToBack(Impeller):
         test_points_sec1,
         guarantee_point_sec2,
         test_points_sec2,
+        reynolds_correction=False,
         speed=None,
     ):
         self.guarantee_point_sec1 = guarantee_point_sec1
         self.guarantee_point_sec2 = guarantee_point_sec2
+        self._test_points_sec1_original = [
+            deepcopy(point) for point in test_points_sec1
+        ]
+        self._test_points_sec2_original = [
+            deepcopy(point) for point in test_points_sec2
+        ]
         self.test_points_sec1 = test_points_sec1
         self.test_points_sec2 = test_points_sec2
         if speed is None:
             speed = guarantee_point_sec1.speed
         self.speed = speed
+        self.reynolds_correction = reynolds_correction
 
         # points for test flange conditions
         self.points_flange_t_sec1 = test_points_sec1
@@ -398,168 +463,156 @@ class BackToBack(Impeller):
         self.k_div_wall = np.zeros(
             len(test_points_sec1), dtype=np.object
         )  # array with div wall seal constants
+
+        for point in test_points_sec1:
+            if point.div_wall_flow_m:
+                point.first_section_discharge_flow_m = (
+                    point.flow_m + point.div_wall_flow_m
+                )
         for i, point in enumerate(test_points_sec1):
-            # if point.first_section_discharge_flow_m | point.div_wall_flow_m:
-            ms1f_t = point.flow_m
-            if point.balance_line_flow_m:
-                mbal_t = point.balance_line_flow_m
-            else:
-                mbal_t = 0 * point.flow_m
-
-            if point.seal_gas_flow_m:
-                mseal_t = point.seal_gas_flow_m
-            else:
-                mseal_t = 0 * point.flow_m
-
-            mend_t = mbal_t - (0.95 * mseal_t) / 2
-            point.end_seal_flow_m = mend_t
             if point.first_section_discharge_flow_m:
                 md1f_t = point.first_section_discharge_flow_m
+                ms1f_t = point.flow_m
+                mbal_t = point.balance_line_flow_m
+                mseal_t = point.seal_gas_flow_m
+                mend_t = mbal_t - (0.95 * mseal_t) / 2
+                point.end_seal_flow_m = mend_t
                 mdiv_t = md1f_t - ms1f_t - mend_t - 0.95 * mseal_t
                 point.div_wall_flow_m = mdiv_t
-            elif point.div_wall_flow_m:
-                mdiv_t = point.div_wall_flow_m
-                md1f_t = mdiv_t + ms1f_t + mend_t + 0.95 * mseal_t
-                point.first_section_discharge_flow_m = md1f_t
+                ms1r_t = ms1f_t + mend_t + 0.95 * mseal_t
+
+                ps1f_t = point.suc.p()
+                Ts1f_t = point.suc.T()
+
+                pd1f_t = point.disch.p()
+                Td1f_t = point.disch.T()
+                pd2f_t = point.div_wall_upstream_pressure
+                Td2f_t = point.div_wall_upstream_temperature
+                Tseal_t = point.seal_gas_temperature
+
+                Tend_t = point.end_seal_downstream_state.T()
+
+                k_end = k_seal(
+                    flow_m=mend_t,
+                    state_up=point.end_seal_upstream_state,
+                    state_down=point.end_seal_downstream_state,
+                )
+                self.k_end_seal[i] = k_end
+
+                k_div_wall = k_seal(
+                    flow_m=mdiv_t,
+                    state_up=point.div_wall_upstream_state,
+                    state_down=point.div_wall_downstream_state,
+                )
+                self.k_div_wall[i] = k_div_wall
+                Tdiv_t = point.div_wall_downstream_state.T()
+                Ts1r_t = (
+                    ms1f_t * Ts1f_t + mend_t * Tend_t + 0.95 * mseal_t * Tseal_t
+                ) / (ms1f_t + mend_t + 0.95 * mseal_t)
+                Td1r_t = (md1f_t * Td1f_t - mdiv_t * Tdiv_t) / (md1f_t - mdiv_t)
+                suc_sec1_rotor_t = State(
+                    p=ps1f_t, T=Ts1r_t, fluid=point.suc.fluid
+                )
+                disch_sec1_rotor_t = State(
+                    p=pd1f_t, T=Td1r_t, fluid=point.suc.fluid
+                )
+
+                test_points_sec1_rotor[i] = Point(
+                    suc=suc_sec1_rotor_t,
+                    disch=disch_sec1_rotor_t,
+                    flow_m=ms1r_t,
+                    speed=point.speed,
+                    b=point.b,
+                    D=point.D,
+                    casing_area=point.casing_area,
+                    casing_temperature=point.casing_temperature,
+                    ambient_temperature=point.ambient_temperature,
+                )
+
+            # use calculated k_end_seal and k_div_wall to calculate seal mass flow
+            # use manual mean, since np.mean removes the units
+            if (self.k_end_seal == 0).all():
+                k_end_seal_mean = Q_(
+                    0, "kelvin**0.5 kilogram**0.5 mole**0.5/(pascal second)"
+                )
             else:
-                mdiv_t = 0 * point.flow_m
-                md1f_t = mdiv_t + ms1f_t + mend_t + 0.95 * mseal_t
+                k_end_seal_mean = sum(self.k_end_seal[self.k_end_seal != 0]) / len(
+                    self.k_end_seal[self.k_end_seal != 0]
+                )
+            if (self.k_div_wall == 0).all():
+                k_div_wall_mean = Q_(
+                    0, "kelvin**0.5 kilogram**0.5 mole**0.5/(pascal second)"
+                )
+            else:
+                k_div_wall_mean = sum(self.k_div_wall[self.k_div_wall != 0]) / len(
+                    self.k_div_wall[self.k_div_wall != 0]
+                )
+
+        for i, point in enumerate(test_points_sec1):
+            if not point.first_section_discharge_flow_m:
+
+                self.k_end_seal[i] = k_end_seal_mean
+                end_seal_flow_m = flow_m_seal(
+                    k_seal=k_end_seal_mean,
+                    state_up=point.end_seal_upstream_state,
+                    state_down=point.end_seal_downstream_state,
+                )
+
+                self.k_div_wall[i] = k_div_wall_mean
+                div_wall_flow_m = flow_m_seal(
+                    k_seal=k_div_wall_mean,
+                    state_up=point.div_wall_upstream_state,
+                    state_down=point.div_wall_downstream_state,
+                )
+
+                # calculate balance line and rotor suction flow
+                mseal_t = point.seal_gas_flow_m
+                mend_t = end_seal_flow_m
+                point.end_seal_flow_m = mend_t
+
+                mbal_t = mend_t + (0.95 * mseal_t) / 2
+                point.balance_line_flow_m = mbal_t
+
+                ms1f_t = point.flow_m
+                ms1r_t = ms1f_t + mend_t + 0.95 * mseal_t
+
+                # calculate discharge flow
+                mdiv_t = div_wall_flow_m
                 point.div_wall_flow_m = mdiv_t
+                md1f_t = mdiv_t + ms1f_t + mend_t + 0.95 * mseal_t
                 point.first_section_discharge_flow_m = md1f_t
 
-            ms1r_t = ms1f_t + mend_t + 0.95 * mseal_t
+                Ts1f_t = point.suc.T()
+                Tend_t = point.end_seal_downstream_state.T()
+                Tdiv_t = point.div_wall_downstream_state.T()
+                Tseal_t = point.seal_gas_temperature
+                Td1f_t = point.disch.T()
+                ps1f_t = point.suc.p()
+                pd1f_t = point.disch.p()
 
-            ps1f_t = point.suc.p()
-            Ts1f_t = point.suc.T()
+                Ts1r_t = (
+                    ms1f_t * Ts1f_t + mend_t * Tend_t + 0.95 * mseal_t * Tseal_t
+                ) / (ms1f_t + mend_t + 0.95 * mseal_t)
+                Td1r_t = (md1f_t * Td1f_t - mdiv_t * Tdiv_t) / (md1f_t - mdiv_t)
 
-            pd1f_t = point.disch.p()
-            Td1f_t = point.disch.T()
-            pd2f_t = point.div_wall_upstream_pressure
-            Td2f_t = point.div_wall_upstream_temperature
-            Tseal_t = point.seal_gas_temperature
+                suc_sec1_rotor_t = State(
+                    p=ps1f_t, T=Ts1r_t, fluid=point.suc.fluid
+                )
+                disch_sec1_rotor_t = State(
+                    p=pd1f_t, T=Td1r_t, fluid=point.suc.fluid
+                )
 
-            Tend_t = point.end_seal_downstream_state.T()
-
-            k_end = k_seal(
-                flow_m=mend_t,
-                state_up=point.end_seal_upstream_state,
-                state_down=point.end_seal_downstream_state,
-            )
-            self.k_end_seal[i] = k_end
-
-            k_div_wall = k_seal(
-                flow_m=mdiv_t,
-                state_up=point.div_wall_upstream_state,
-                state_down=point.div_wall_downstream_state,
-            )
-            self.k_div_wall[i] = k_div_wall
-            Tdiv_t = point.div_wall_downstream_state.T()
-            Ts1r_t = (
-                ms1f_t * Ts1f_t + mend_t * Tend_t + 0.95 * mseal_t * Tseal_t
-            ) / (ms1f_t + mend_t + 0.95 * mseal_t)
-            Td1r_t = (md1f_t * Td1f_t - mdiv_t * Tdiv_t) / (md1f_t - mdiv_t)
-            suc_sec1_rotor_t = State.define(
-                p=ps1f_t, T=Ts1r_t, fluid=point.suc.fluid
-            )
-            disch_sec1_rotor_t = State.define(
-                p=pd1f_t, T=Td1r_t, fluid=point.suc.fluid
-            )
-
-            test_points_sec1_rotor[i] = Point(
-                suc=suc_sec1_rotor_t,
-                disch=disch_sec1_rotor_t,
-                flow_m=ms1r_t,
-                speed=point.speed,
-                b=point.b,
-                D=point.D,
-                casing_area=point.casing_area,
-                casing_temperature=point.casing_temperature,
-                ambient_temperature=point.ambient_temperature,
-            )
-
-        k_end_seal_mean = sum(self.k_end_seal) / len(
-            self.k_end_seal
-        )
-
-        k_div_wall_mean = sum(self.k_div_wall) / len(
-            self.k_div_wall
-        )
-
-        ##############################################
-        ##### Acho que não precisa - Timbó verificar
-        ##############################################
-        # for i, point in enumerate(test_points_sec1):
-        #     if not point.first_section_discharge_flow_m:
-        #         # use calculated k_end_seal and k_div_wall to calculate seal mass flow
-        #         # use manual mean, since np.mean removes the units
-        #         k_end_seal_mean = sum(self.k_end_seal[self.k_end_seal != 0]) / len(
-        #             self.k_end_seal[self.k_end_seal != 0]
-        #         )
-        #         self.k_end_seal[i] = k_end_seal_mean
-        #         end_seal_flow_m = flow_m_seal(
-        #             k_seal=k_end_seal_mean,
-        #             state_up=point.end_seal_upstream_state,
-        #             state_down=point.end_seal_downstream_state,
-        #         )
-        #         k_div_wall_mean = sum(self.k_div_wall[self.k_div_wall != 0]) / len(
-        #             self.k_div_wall[self.k_div_wall != 0]
-        #         )
-        #         self.k_div_wall[i] = k_div_wall_mean
-        #         div_wall_flow_m = flow_m_seal(
-        #             k_seal=k_div_wall_mean,
-        #             state_up=point.div_wall_upstream_state,
-        #             state_down=point.div_wall_downstream_state,
-        #         )
-        #
-        #         # calculate balance line and rotor suction flow
-        #         mseal_t = point.seal_gas_flow_m
-        #         mend_t = end_seal_flow_m
-        #         point.end_seal_flow_m = mend_t
-        #
-        #         mbal_t = mend_t + (0.95 * mseal_t) / 2
-        #         point.balance_line_flow_m = mbal_t
-        #
-        #         ms1f_t = point.flow_m
-        #         ms1r_t = ms1f_t + mend_t + 0.95 * mseal_t
-        #
-        #         # calculate discharge flow
-        #         mdiv_t = div_wall_flow_m
-        #         point.div_wall_flow_m = mdiv_t
-        #         md1f_t = mdiv_t + ms1f_t + mend_t + 0.95 * mseal_t
-        #         point.first_section_discharge_flow_m = md1f_t
-        #
-        #         Ts1f_t = point.suc.T()
-        #         Tend_t = point.end_seal_downstream_state.T()
-        #         Tdiv_t = point.div_wall_downstream_state.T()
-        #         Tseal_t = point.seal_gas_temperature
-        #         Td1f_t = point.disch.T()
-        #         ps1f_t = point.suc.p()
-        #         pd1f_t = point.disch.p()
-        #
-        #         Ts1r_t = (
-        #             ms1f_t * Ts1f_t + mend_t * Tend_t + 0.95 * mseal_t * Tseal_t
-        #         ) / (ms1f_t + mend_t + 0.95 * mseal_t)
-        #         Td1r_t = (md1f_t * Td1f_t - mdiv_t * Tdiv_t) / (md1f_t - mdiv_t)
-        #
-        #         suc_sec1_rotor_t = State.define(
-        #             p=ps1f_t, T=Ts1r_t, fluid=point.suc.fluid
-        #         )
-        #         disch_sec1_rotor_t = State.define(
-        #             p=pd1f_t, T=Td1r_t, fluid=point.suc.fluid
-        #         )
-        #
-        #         test_points_sec1_rotor[i] = Point(
-        #             suc=suc_sec1_rotor_t,
-        #             disch=disch_sec1_rotor_t,
-        #             flow_m=ms1r_t,
-        #             speed=point.speed,
-        #             b=point.b,
-        #             D=point.D,
-        #             casing_area=point.casing_area,
-        #             casing_temperature=point.casing_temperature,
-        #             ambient_temperature=point.ambient_temperature,
-        #         )
-        ############################################################################
+                test_points_sec1_rotor[i] = Point(
+                    suc=suc_sec1_rotor_t,
+                    disch=disch_sec1_rotor_t,
+                    flow_m=ms1r_t,
+                    speed=point.speed,
+                    b=point.b,
+                    D=point.D,
+                    casing_area=point.casing_area,
+                    casing_temperature=point.casing_temperature,
+                    ambient_temperature=point.ambient_temperature,
+                )
 
         self.k_end_seal_mean = k_end_seal_mean
         self.k_div_wall_mean = k_div_wall_mean
@@ -569,17 +622,8 @@ class BackToBack(Impeller):
         test_points_sec2_rotor = np.full(len(test_points_sec1), np.nan, dtype=np.object)
         for i, point_f in enumerate(test_points_sec2):
             ms2f_t = point_f.flow_m
-
-            if point_f.balance_line_flow_m:
-                mbal_t = point_f.balance_line_flow_m
-            else:
-                mbal_t = 0 * point_f.flow_m
-
-            if point_f.seal_gas_flow_m:
-                mseal_t = point_f.seal_gas_flow_m
-            else:
-                mseal_t = 0 * point_f.flow_m
-
+            mbal_t = point_f.balance_line_flow_m
+            mseal_t = point_f.seal_gas_flow_m
             mend_t = mbal_t - 0.95 * mseal_t / 2
             ms2r_t = ms2f_t - mend_t
             point_r = Point(
@@ -615,9 +659,10 @@ class BackToBack(Impeller):
                 suc=guarantee_point_sec1.suc,
                 speed=self.speed,
                 find="volume_ratio",
+                reynolds_correction=self.reynolds_correction,
             )
             # determine rotor specified suction state
-            end_seal_state_upstream_sp = State.define(
+            end_seal_state_upstream_sp = State(
                 p=initial_point.disch.p(),
                 T=guarantee_point_sec2.suc.T(),
                 fluid=initial_point.suc.fluid,
@@ -629,7 +674,7 @@ class BackToBack(Impeller):
             Tend_sp = end_seal_state_downstream_sp.T()
 
             mend_sp = flow_m_seal(
-                k_seal=self.k_end_seal[i],
+                k_seal=k_end_seal,
                 state_up=end_seal_state_upstream_sp,
                 state_down=end_seal_state_downstream_sp,
             )
@@ -663,7 +708,7 @@ class BackToBack(Impeller):
 
             ms1f_sp_array[i] = ms1f_sp
 
-            rotor_sp_sec1_suc = ccp.State.define(
+            rotor_sp_sec1_suc = ccp.State(
                 p=guarantee_point_sec1.suc.p(),
                 T=Ts1r_sp,
                 fluid=guarantee_point_sec1.suc.fluid,
@@ -673,13 +718,14 @@ class BackToBack(Impeller):
                 suc=rotor_sp_sec1_suc,
                 speed=self.speed,
                 find="volume_ratio",
+                reynolds_correction=self.reynolds_correction,
             )
             self.points_rotor_sp_sec1.append(point_r_sp)
         self.imp_rotor_sp_sec1 = Impeller(self.points_rotor_sp_sec1)
 
         # estimate rotor guarantee flow using fd conditions
         end_seal_flow_m_sp = flow_m_seal(
-            k_seal=k_end_seal_mean,
+            k_seal=k_end_seal,
             state_up=guarantee_point_sec2.suc,
             state_down=guarantee_point_sec1.suc,
         )
@@ -692,21 +738,22 @@ class BackToBack(Impeller):
         ps2f_sp = disch_r_sp.p() - (
             guarantee_point_sec1.disch.p() - guarantee_point_sec2.suc.p()
         )
-        suc2f_sp = State.define(
+        suc2f_sp = State(
             p=ps2f_sp,
             T=guarantee_point_sec2.suc.T(),
             fluid=guarantee_point_sec2.suc.fluid,
         )
-        for i, point_r_t in enumerate(self.points_rotor_t_sec2):
+        for point_r_t in self.points_rotor_t_sec2:
             point_r_sp = Point.convert_from(
                 original_point=point_r_t,
                 suc=suc2f_sp,
                 speed=self.speed,
                 find="volume_ratio",
+                reynolds_correction=self.reynolds_correction,
             )
             self.points_rotor_sp_sec2.append(point_r_sp)
             mend_sp = flow_m_seal(
-                k_seal=self.k_end_seal[i],
+                k_seal=k_end_seal,
                 state_up=guarantee_point_sec2.suc,
                 state_down=guarantee_point_sec1.suc,
             )
@@ -730,7 +777,7 @@ class BackToBack(Impeller):
             self.points_rotor_sp_sec1, ms1f_sp_array, self.k_end_seal, self.k_div_wall
         ):
             # calculate div wall flow
-            suc_sec2 = ccp.State.define(
+            suc_sec2 = ccp.State(
                 p=point_r_sp.disch.p(),
                 T=guarantee_point_sec2.suc.T(),
                 fluid=guarantee_point_sec2.suc.fluid,
@@ -757,7 +804,7 @@ class BackToBack(Impeller):
             # calculate flange disch
             Td1r_sp = point_r_sp.disch.T()
             Td1f_sp = (ms1r_sp * Td1r_sp + mdiv_sp * Tdiv_sp) / (ms1r_sp + mdiv_sp)
-            disch_f = ccp.State.define(
+            disch_f = ccp.State(
                 p=point_r_sp.disch.p(), T=Td1f_sp, fluid=guarantee_point_sec1.suc.fluid
             )
             point_flange = Point(
@@ -770,7 +817,9 @@ class BackToBack(Impeller):
             )
             self.points_flange_sp_sec1.append(point_flange)
             self.points_flange_sp_sec1[-1].div_wall_flow_m = mdiv_sp
-            self.points_flange_sp_sec1[-1].first_section_discharge_flow_m = mdiv_sp + ms1r_sp
+            self.points_flange_sp_sec1[-1].first_section_discharge_flow_m = (
+                mdiv_sp + ms1r_sp
+            )
         self.imp_flange_sp_sec1 = Impeller(self.points_flange_sp_sec1)
 
     def point_sec1(self, *args, **kwargs):
@@ -781,7 +830,7 @@ class BackToBack(Impeller):
         ps2f_sp = p_sec1.disch.p() - (
             self.guarantee_point_sec1.disch.p() - self.guarantee_point_sec2.suc.p()
         )
-        suc2f_sp = State.define(
+        suc2f_sp = State(
             p=ps2f_sp,
             T=self.guarantee_point_sec2.suc.T(),
             fluid=self.guarantee_point_sec2.suc.fluid,
@@ -810,10 +859,42 @@ class BackToBack(Impeller):
             state_down=self.guarantee_point_sec1.suc,
         )
         ms2r_sp = p_sec2.flow_m - end_seal_flow_m_sp
-        p_sec2.power = ms2r_sp * p_sec2.head * p_sec2.eff
+        p_sec2.power = ms2r_sp * p_sec2.head / p_sec2.eff
 
         return p_sec2
 
+    def calculate_speed_to_match_discharge_pressure(self):
+        """Calculate the speed to match the discharge pressure of the guarantee point."""
+        test_points_sec1 = deepcopy(self._test_points_sec1_original)
+        test_points_sec2 = deepcopy(self._test_points_sec2_original)
+
+        def calculate_disch_pressure_delta(x):
+            compressor = BackToBack(
+                guarantee_point_sec1=self.guarantee_point_sec1,
+                guarantee_point_sec2=self.guarantee_point_sec2,
+                test_points_sec1=test_points_sec1,
+                test_points_sec2=test_points_sec2,
+                speed=x,
+                reynolds_correction=self.reynolds_correction,
+            )
+
+            point = compressor.point_sec2(
+                flow_m=self.guarantee_point_sec2.flow_m, speed=x
+            )
+            delta_p = point.disch.p().m - self.guarantee_point_sec2.disch.p().m
+            return delta_p
+
+        new_speed = newton(calculate_disch_pressure_delta, self.speed.m)
+
+        self.__init__(
+            guarantee_point_sec1=self.guarantee_point_sec1,
+            guarantee_point_sec2=self.guarantee_point_sec2,
+            test_points_sec1=test_points_sec1,
+            test_points_sec2=test_points_sec2,
+            speed=new_speed,
+            reynolds_correction=self.reynolds_correction,
+        )
+
 
 @check_units
 def k_seal(flow_m, state_up, state_down):
@@ -832,12 +913,12 @@ def k_seal(flow_m, state_up, state_down):
 
     Returns
     -------
-    k_seal : pint.Quantity
+    k_end_seal : pint.Quantity
         Seal constant (kelvin ** 0.5 * kilogram ** 0.5 * mole ** 0.5 / pascal / second).
     """
     p_up = state_up.p()
     z_up = state_up.z()
-    T_up = state_up.T().to('K')
+    T_up = state_up.T().to("K")
     MW = state_up.molar_mass()
     p_down = state_down.p()
 
@@ -868,7 +949,7 @@ def flow_m_seal(k_seal, state_up, state_down):
     """
     p_up = state_up.p()
     z_up = state_up.z()
-    T_up = state_up.T().to('K')
+    T_up = state_up.T().to("K")
     MW = state_up.molar_mass()
     p_down = state_down.p()
 
