@@ -257,7 +257,7 @@ class Impeller:
         disch_p = func_p(flow_v)
 
         p0 = self.points[0]
-        disch = State.define(p=disch_p, T=disch_T, fluid=p0.suc.fluid)
+        disch = State(p=disch_p, T=disch_T, fluid=p0.suc.fluid)
 
         point = Point(
             suc=p0.suc, disch=disch, flow_v=flow_v, speed=speed, b=p0.b, D=p0.D
@@ -323,7 +323,7 @@ class Impeller:
                 curves[1][i].disch.p().m,
             )
 
-            disch = State.define(p=disch_p, T=disch_T, fluid=p0.suc.fluid)
+            disch = State(p=disch_p, T=disch_T, fluid=p0.suc.fluid)
 
             p = Point(
                 suc=p0.suc,
@@ -609,6 +609,14 @@ class Impeller:
                         curves[curve][speed]["x"] = [
                             flow.to(flow_units).m for flow in flow_curve
                         ]
+                else:
+                    flow_curve = [
+                        Q_(flow, args[f"flow_units_{curve}"])
+                        for flow in curves[curve][speed]["x"]
+                    ]
+                    curves[curve][speed]["x"] = [
+                        flow.to(flow_units).m for flow in flow_curve
+                    ]
                 if curves[curve][speed]["x"][0] > min_x:
                     min_x = curves[curve][speed]["x"][0]
                 if curves[curve][speed]["x"][-1] < max_x:
@@ -746,7 +754,7 @@ class Impeller:
         ...    pentane=0.03,
         ...    hexane=0.01,
         ... )
-        >>> suc_fd = State.define(p=Q_(3876, "kPa"), T=Q_(11, "degC"), fluid=composition_fd)
+        >>> suc_fd = State(p=Q_(3876, "kPa"), T=Q_(11, "degC"), fluid=composition_fd)
         >>> imp = ccp.Impeller.load_from_dict_isis(
         ...    suc=suc_fd,
         ...    head_curves=head_curves_dict,
@@ -1041,7 +1049,7 @@ def impeller_example():
     test_dir = Path(__file__).parent / "tests"
     data_dir = test_dir / "data"
 
-    suc = State.define(
+    suc = State(
         p=Q_(4.08, "bar"),
         T=Q_(33.6, "degC"),
         fluid={
