@@ -33,8 +33,32 @@ class Point:
     suc, eff, volume_ratio : ccp.State, float, float
         Suction state, polytropic efficiency and volume ratio.
     suc, pres_ratio, disch_T : ccp.State, float, pint.Quantity or float
-    b, D : pint.Quantity, float
-        Impeller width and diameter.
+        Suction state, pressure ration and discharge temperature.
+    b : pint.Quantity, optional
+        Impeller width (m).
+        This value is used to calculate the machine Mach and Reynolds numbers.
+    D : pint.Quantity, optional
+        Impeller diameter (m).
+        This value is used to calculate the machine Mach and Reynolds numbers.
+    surface_roughness : pint.Quantity, optional
+        Gas passage mean surface roughness (m).
+        Used in the reynolds correction calculation.
+        Default value is 3.048e-6 m.
+    casing_area : pint.Quantity, optional
+        Compressor case area used to calculate case heat loss (m²).
+    casing_temperature : pint.Quantity, optional
+        Compressor case temperature used to calculate case heat loss (degK).
+    ambient_temperature : pint.Quantity, optional
+        Ambient temperature used to calculate case heat loss (degK).
+    convection_constant : pint.Quantity, optional
+        Heat transfer (convection) constant (W / m²degK).
+        Default value is 13.6.
+    polytropic_method : str, optional
+        Polytropic method used for head and efficiency calculation.
+        Options are: "mallen_saveille", "sandberg_colby", "schultz" and "huntington".
+        The default is "schultz".
+        The default value can be changed in a global level with:
+        ccp.config.POLYTROPIC_METHOD = "<desired value>"
 
     Returns
     -------
@@ -73,15 +97,14 @@ class Point:
         Impeller width (m).
     D : pint.Quantity
         Impeller diameter (m).
-    casing_area : pint.Quantity, optional
+    casing_area : pint.Quantity
         Compressor case area used to calculate case heat loss (m²).
-    casing_temperature : pint.Quantity, optional
+    casing_temperature : pint.Quantity
         Compressor case temperature used to calculate case heat loss (degK).
-    ambient_temperature : pint.Quantity, optional
+    ambient_temperature : pint.Quantity
         Ambient temperature used to calculate case heat loss (degK).
-    convection_constant : pint.Quantity, optional
+    convection_constant : pint.Quantity
         Heat transfer (convection) constant (W / m²degK).
-        Default value is 13.6.
     reynolds : pint.Quantity
         Reynolds number (dimensionless).
     mach : pint.Quantity
@@ -94,14 +117,10 @@ class Point:
         Ratio between Reynolds for this point and the original point from which it was converted from.
     mach_diff : float
         Difference between Mach for this point and the original point from which it was converted from.
-    volume_ratio_ratio = 1.0
+    volume_ratio_ratio : float
         Ratio between volume_ratio for this point and the original point from which it was converted from.
-    polytropic_method : str, optional
+    polytropic_method : str
         Polytropic method used for head and efficiency calculation.
-        Options are: "mallen_saveille", "sandberg_colby", "schultz" and "huntington".
-        The default is "schultz".
-        The default value can be changed in a global level with:
-        ccp.config.POLYTROPIC_METHOD = "<desired value>"
     """
 
     @check_units
@@ -121,16 +140,15 @@ class Point:
         volume_ratio=None,
         pressure_ratio=None,
         disch_T=None,
-        b=None,
-        D=None,
+        b=Q_(0.005, "m"),
+        D=Q_(0.5, "m"),
+        surface_roughness=Q_(3.175e-6, "m"),
         casing_area=None,
         casing_temperature=None,
         ambient_temperature=None,
         convection_constant=Q_(13.6, "W/(m²*degK)"),
         polytropic_method=None,
     ):
-        if b is None or D is None:
-            raise ValueError("Arguments b and D must be provided.")
         if polytropic_method is None:
             polytropic_method = ccp.config.POLYTROPIC_METHOD
 
@@ -155,6 +173,7 @@ class Point:
 
         self.b = b
         self.D = D
+        self.surface_roughness = surface_roughness
 
         self.casing_area = casing_area
         self.casing_temperature = casing_temperature
@@ -305,7 +324,7 @@ class Point:
         disch_rho = 1 / disch_v
 
         # consider first an isentropic compression
-        disch = State.define(rho=disch_rho, s=suc.s(), fluid=suc.fluid)
+        disch = State(rho=disch_rho, s=suc.s(), fluid=suc.fluid)
 
         def update_state(x, update_type):
             if update_type == "pressure":
@@ -323,7 +342,7 @@ class Point:
         except ValueError:
             # re-instantiate disch, since update with temperature not converging
             # might break the state
-            disch = State.define(rho=disch_rho, s=suc.s(), fluid=suc.fluid)
+            disch = State(rho=disch_rho, s=suc.s(), fluid=suc.fluid)
             newton(update_state, disch.p().magnitude, args=("pressure",), tol=1e-1)
 
         self.disch = disch
@@ -416,7 +435,7 @@ class Point:
         disch_T = self.disch_T
         pressure_ratio = self.pressure_ratio
         disch_p = suc.p() * pressure_ratio
-        self.disch = State.define(p=disch_p, T=disch_T, fluid=suc.fluid)
+        self.disch = State(p=disch_p, T=disch_T, fluid=suc.fluid)
         self._calc_from_disch_flow_v_speed_suc()
 
     def _calc_from_disch_T_flow_m_pressure_ratio_speed_suc(self):
@@ -424,12 +443,20 @@ class Point:
         disch_T = self.disch_T
         pressure_ratio = self.pressure_ratio
         disch_p = suc.p() * pressure_ratio
-        self.disch = State.define(p=disch_p, T=disch_T, fluid=suc.fluid)
+        self.disch = State(p=disch_p, T=disch_T, fluid=suc.fluid)
         self._calc_from_disch_flow_m_speed_suc()
 
     @classmethod
     @check_units
-    def convert_from(cls, original_point, suc=None, find="speed", speed=None, **kwargs):
+    def convert_from(
+        cls,
+        original_point,
+        suc=None,
+        find="speed",
+        speed=None,
+        reynolds_correction=False,
+        **kwargs,
+    ):
         """Convert point from an original point.
 
         Parameters
@@ -442,18 +469,58 @@ class Point:
             Options are "speed" or "volume_ratio", default is "speed".
         speed : float, pint.Quantity, optional
             Desired speed. If find="speed", this should be None.
+        reynolds_correction : bool, optional
+            If reynolds correction should be applied during the conversion.
+            If True the ASME PTC 10 reynolds correction is applied
 
         The user must provide 3 of the 4 available arguments. The argument which is not
         provided will be calculated.
         """
         if speed is None:
             speed = original_point.speed
+
+        eff_converted = original_point.eff
+        psi_converted = original_point.psi
+
+        if reynolds_correction:
+            rc_original = 0.988 / original_point.reynolds**0.243
+            rb_original = np.log(0.000125 + 13.67 / original_point.reynolds) / np.log(
+                original_point.surface_roughness.to("in").m
+                + (13.67 / original_point.reynolds)
+            )
+            ra_original = (
+                0.066
+                + 0.934
+                * ((4.8e6 * original_point.b.to("ft").m) / original_point.reynolds)
+                ** rc_original
+            )
+
+            reynolds_converted = reynolds(
+                suc=suc, speed=speed, b=original_point.b, D=original_point.D
+            )
+            rc_converted = 0.988 / reynolds_converted**0.243
+            rb_converted = np.log(0.000125 + 13.67 / reynolds_converted) / np.log(
+                original_point.surface_roughness.to("in").m
+                + (13.67 / reynolds_converted)
+            )
+            ra_converted = (
+                0.066
+                + 0.934
+                * ((4.8e6 * original_point.b.to("ft").m) / reynolds_converted)
+                ** rc_converted
+            )
+
+            eff_converted = 1 - (1 - original_point.eff) * (
+                ra_converted / ra_original
+            ) * (rb_converted / rb_original)
+            psi_converted = original_point.psi * (eff_converted / original_point.eff)
+
         convert_point_options = {
             "speed": dict(
                 suc=suc,
-                eff=original_point.eff,
+                eff=eff_converted,
                 phi=original_point.phi,
-                psi=original_point.psi,
+                psi=psi_converted,
                 volume_ratio=original_point.volume_ratio,
                 b=original_point.b,
                 D=original_point.D,
@@ -461,9 +528,9 @@ class Point:
             ),
             "volume_ratio": dict(
                 suc=suc,
-                eff=original_point.eff,
+                eff=eff_converted,
                 phi=original_point.phi,
-                psi=original_point.psi,
+                psi=psi_converted,
                 speed=speed,
                 b=original_point.b,
                 D=original_point.D,
@@ -511,7 +578,7 @@ class Point:
     @staticmethod
     def _dict_from_load(dict_parameters):
         """Change dict to format that can be used by load constructor."""
-        suc = State.define(
+        suc = State(
             p=Q_(dict_parameters.pop("p")),
             T=Q_(dict_parameters.pop("T")),
             fluid=dict_parameters.pop("fluid"),
@@ -1259,7 +1326,7 @@ def head_reference(suc, disch, num_steps=100):
     """
 
     def calc_step_discharge_temp(T1, p1, p0, h0, v0, e):
-        s1 = State.define(p=p1, T=T1, fluid=suc.fluid)
+        s1 = State(p=p1, T=T1, fluid=suc.fluid)
         h1 = s1.h()
 
         vm = (v0 + s1.v()) / 2
@@ -1286,11 +1353,11 @@ def head_reference(suc, disch, num_steps=100):
 
         # TODO implement p_intervals considering pressure ratio
         for p0, p1 in zip(p_intervals[:-1], p_intervals[1:]):
-            s0 = State.define(p=p0, T=T0, fluid=suc.fluid)
+            s0 = State(p=p0, T=T0, fluid=suc.fluid)
             T1 = newton(
                 calc_step_discharge_temp, (T0 + 1e-3), args=(p1, p0, s0.h(), s0.v(), e)
             )
-            s1 = State.define(p=p1, T=T1, fluid=suc.fluid)
+            s1 = State(p=p1, T=T1, fluid=suc.fluid)
             _ref_H += head_pol(s0, s1)
 
             T0 = T1
@@ -1352,7 +1419,7 @@ def head_reference_2017(suc, disch, num_steps=100):
         p_intervals.append(p)
 
     def calc_step_discharge_z(s1, s0, p1, p0, z0, R, e):
-        state1 = ccp.State.define(p=p1, s=s1, fluid=suc.fluid)
+        state1 = ccp.State(p=p1, s=s1, fluid=suc.fluid)
         z1 = state1.z()
         a = (z0 * (p1 / p0) - z1) / ((p1 / p0) - 1)
         b = (z1 - z0) / ((p1 / p0) - 1)
@@ -1368,11 +1435,11 @@ def head_reference_2017(suc, disch, num_steps=100):
         s0 = suc.s().magnitude
 
         for p0, p1 in zip(p_intervals[:-1], p_intervals[1:]):
-            state0 = ccp.State.define(p=p0, s=s0, fluid=suc.fluid)
+            state0 = ccp.State(p=p0, s=s0, fluid=suc.fluid)
             z0 = state0.z()
 
             s1 = newton(calc_step_discharge_z, (s0 + 1e-8), args=(s0, p1, p0, z0, R, e))
-            state1 = ccp.State.define(p=p1, s=s1, fluid=suc.fluid)
+            state1 = ccp.State(p=p1, s=s1, fluid=suc.fluid)
             _ref_H_2017 += ccp.point.head_pol(state0, state1)
 
             s0 = s1
@@ -1569,7 +1636,7 @@ def eff_pol_huntington(suc, disch):
     error = 1
     n = 0
     while error > 1e-10:
-        state3 = State.define(p=p3, T=T3, fluid=suc.fluid)
+        state3 = State(p=p3, T=T3, fluid=suc.fluid)
         s3 = state3.s()
         z3 = state3.z()
         cp3 = state3.cp()
@@ -1818,7 +1885,7 @@ def disch_from_suc_head_eff(suc, head, eff, polytropic_method=None):
     h_disch = head / eff + suc.h()
 
     #  consider first an isentropic compression
-    disch = State.define(h=h_disch, s=suc.s(), fluid=suc.fluid)
+    disch = State(h=h_disch, s=suc.s(), fluid=suc.fluid)
 
     def update_pressure(p):
         disch.update(h=h_disch, p=p)
@@ -1852,7 +1919,7 @@ def disch_from_suc_disch_p_eff(suc, disch_p, eff, polytropic_method=None):
     if polytropic_method is None:
         polytropic_method = ccp.config.POLYTROPIC_METHOD
 
-    disch = ccp.State.define(p=disch_p, s=suc.s(), fluid=suc.fluid)
+    disch = ccp.State(p=disch_p, s=suc.s(), fluid=suc.fluid)
     eff_calc_func = globals()[f"eff_pol_{polytropic_method}"]
 
     def update_state(x):
