@@ -1,7 +1,13 @@
 import pytest
 import numpy as np
 from numpy.testing import assert_allclose
-from ccp.compressor import StraightThrough, Point1Sec, Point2Sec, BackToBack
+from ccp.compressor import (
+    StraightThrough,
+    Point1Sec,
+    PointFirstSection,
+    PointSecondSection,
+    BackToBack,
+)
 from ccp.point import Point
 from ccp.state import State
 from ccp import Q_
@@ -14,7 +20,7 @@ def test_point1sec():
         speed=Q_(7894, "RPM"),
         b=Q_(28.5, "mm"),
         D=Q_(365, "mm"),
-        suc=State.define(
+        suc=State(
             p=Q_(1.826, "bar"),
             T=Q_(296.7, "degK"),
             fluid={
@@ -24,7 +30,7 @@ def test_point1sec():
                 "oxygen": 0.0003,
             },
         ),
-        disch=State.define(
+        disch=State(
             p=Q_(6.142, "bar"),
             T=Q_(392.1, "degK"),
             fluid={
@@ -69,8 +75,8 @@ def straight_through():
         "carbon dioxide": 9.259,
         "water": 0.200,
     }
-    suc_sp = State.define(p=Q_(16.99, "bar"), T=Q_(38.4, "degC"), fluid=fluid_sp)
-    disch_sp = State.define(p=Q_(80.38, "bar"), T=Q_(164.6, "degC"), fluid=fluid_sp)
+    suc_sp = State(p=Q_(16.99, "bar"), T=Q_(38.4, "degC"), fluid=fluid_sp)
+    disch_sp = State(p=Q_(80.38, "bar"), T=Q_(164.6, "degC"), fluid=fluid_sp)
     guarantee_point = Point(
         suc=suc_sp,
         disch=disch_sp,
@@ -86,7 +92,7 @@ def straight_through():
             speed=Q_(7894, "RPM"),
             b=Q_(28.5, "mm"),
             D=Q_(365, "mm"),
-            suc=State.define(
+            suc=State(
                 p=Q_(1.826, "bar"),
                 T=Q_(296.7, "degK"),
                 fluid={
@@ -96,7 +102,7 @@ def straight_through():
                     "oxygen": 0.0003,
                 },
             ),
-            disch=State.define(
+            disch=State(
                 p=Q_(6.142, "bar"),
                 T=Q_(392.1, "degK"),
                 fluid={
@@ -124,7 +130,7 @@ def straight_through():
             speed=Q_(7981, "RPM"),
             b=Q_(28.5, "mm"),
             D=Q_(365, "mm"),
-            suc=State.define(
+            suc=State(
                 p=Q_(1.51, "bar"),
                 T=Q_(297, "degK"),
                 fluid={
@@ -134,7 +140,7 @@ def straight_through():
                     "oxygen": 0.0003,
                 },
             ),
-            disch=State.define(
+            disch=State(
                 p=Q_(6.306, "bar"),
                 T=Q_(399.9, "degK"),
                 fluid={
@@ -162,7 +168,7 @@ def straight_through():
             speed=Q_(7984, "RPM"),
             b=Q_(28.5, "mm"),
             D=Q_(365, "mm"),
-            suc=State.define(
+            suc=State(
                 p=Q_(1.553, "bar"),
                 T=Q_(296.3, "degK"),
                 fluid={
@@ -172,7 +178,7 @@ def straight_through():
                     "oxygen": 0.0003,
                 },
             ),
-            disch=State.define(
+            disch=State(
                 p=Q_(7.526, "bar"),
                 T=Q_(409.9, "degK"),
                 fluid={
@@ -200,7 +206,7 @@ def straight_through():
             speed=Q_(7981, "RPM"),
             b=Q_(28.5, "mm"),
             D=Q_(365, "mm"),
-            suc=State.define(
+            suc=State(
                 p=Q_(1.432, "bar"),
                 T=Q_(296.3, "degK"),
                 fluid={
@@ -210,7 +216,7 @@ def straight_through():
                     "oxygen": 0.0003,
                 },
             ),
-            disch=State.define(
+            disch=State(
                 p=Q_(7.505, "bar"),
                 T=Q_(415.3, "degK"),
                 fluid={
@@ -238,7 +244,7 @@ def straight_through():
             speed=Q_(7963, "RPM"),
             b=Q_(28.5, "mm"),
             D=Q_(365, "mm"),
-            suc=State.define(
+            suc=State(
                 p=Q_(1.375, "bar"),
                 T=Q_(296, "degK"),
                 fluid={
@@ -248,7 +254,7 @@ def straight_through():
                     "oxygen": 0.0003,
                 },
             ),
-            disch=State.define(
+            disch=State(
                 p=Q_(7.473, "bar"),
                 T=Q_(419.1, "degK"),
                 fluid={
@@ -346,20 +352,29 @@ def test_straight_through(straight_through):
     assert_allclose(point_sp.eff, 0.820459, rtol=1e-5)
 
 
+def test_straight_through_calculate_speed(straight_through):
+    straight_through.calculate_speed_to_match_discharge_pressure()
+    point_sp = straight_through.point(
+        speed=straight_through.speed,
+        flow_m=straight_through.guarantee_point.flow_m,
+    )
+    assert_allclose(point_sp.disch.p(), straight_through.guarantee_point.disch.p())
+
+
 def test_point2sec():
-    p = Point2Sec(
+    p = PointFirstSection(
         flow_m=Q_(4.325, "kg/s"),
         speed=Q_(9096, "RPM"),
         b=Q_(10.5, "mm"),
         D=Q_(365, "mm"),
-        suc=State.define(
+        suc=State(
             p=Q_(5.182, "bar"),
             T=Q_(299.5, "degK"),
             fluid={
                 "carbon dioxide": 1,
             },
         ),
-        disch=State.define(
+        disch=State(
             p=Q_(14.95, "bar"),
             T=Q_(397.6, "degK"),
             fluid={
@@ -407,8 +422,8 @@ def back_to_back():
         "water": 0,
     }
 
-    suc_sp_sec1 = State.define(p=Q_(47.39, "bar"), T=Q_(40, "degC"), fluid=fluid_sp)
-    disch_sp_sec1 = State.define(
+    suc_sp_sec1 = State(p=Q_(47.39, "bar"), T=Q_(40, "degC"), fluid=fluid_sp)
+    disch_sp_sec1 = State(
         p=Q_(136.27, "bar"), T=Q_(123.7, "degC"), fluid=fluid_sp
     )
     guarantee_point_sec1 = Point(
@@ -419,8 +434,8 @@ def back_to_back():
         b=Q_(10.15, "mm"),
         D=Q_(365, "mm"),
     )
-    suc_sp_sec2 = State.define(p=Q_(135.38, "bar"), T=Q_(40, "degC"), fluid=fluid_sp)
-    disch_sp_sec2 = State.define(
+    suc_sp_sec2 = State(p=Q_(135.38, "bar"), T=Q_(40, "degC"), fluid=fluid_sp)
+    disch_sp_sec2 = State(
         p=Q_(250.44, "bar"), T=Q_(86.7, "degC"), fluid=fluid_sp
     )
     guarantee_point_sec2 = Point(
@@ -433,19 +448,19 @@ def back_to_back():
     )
 
     test_points_sec1 = [
-        Point2Sec(
+        PointFirstSection(
             flow_m=Q_(8.716, "kg/s"),
             speed=Q_(9024, "RPM"),
             b=Q_(10.5, "mm"),
             D=Q_(365, "mm"),
-            suc=State.define(
+            suc=State(
                 p=Q_(7.083, "bar"),
                 T=Q_(298.9, "degK"),
                 fluid={
                     "carbon dioxide": 1,
                 },
             ),
-            disch=State.define(
+            disch=State(
                 p=Q_(14.16, "bar"),
                 T=Q_(377.1, "degK"),
                 fluid={
@@ -471,19 +486,19 @@ def back_to_back():
             casing_temperature=Q_(23.895, "degC"),
             ambient_temperature=Q_(0, "degC"),
         ),
-        Point2Sec(
+        PointFirstSection(
             flow_m=Q_(5.724, "kg/s"),
             speed=Q_(9057, "RPM"),
             b=Q_(10.5, "mm"),
             D=Q_(365, "mm"),
-            suc=State.define(
+            suc=State(
                 p=Q_(5.592, "bar"),
                 T=Q_(298.7, "degK"),
                 fluid={
                     "carbon dioxide": 1,
                 },
             ),
-            disch=State.define(
+            disch=State(
                 p=Q_(14.78, "bar"),
                 T=Q_(389.8, "degK"),
                 fluid={
@@ -509,19 +524,19 @@ def back_to_back():
             casing_temperature=Q_(23.895, "degC"),
             ambient_temperature=Q_(0, "degC"),
         ),
-        Point2Sec(
+        PointFirstSection(
             flow_m=Q_(4.325, "kg/s"),
             speed=Q_(9096, "RPM"),
             b=Q_(10.5, "mm"),
             D=Q_(365, "mm"),
-            suc=State.define(
+            suc=State(
                 p=Q_(5.182, "bar"),
                 T=Q_(299.5, "degK"),
                 fluid={
                     "carbon dioxide": 1,
                 },
             ),
-            disch=State.define(
+            disch=State(
                 p=Q_(14.95, "bar"),
                 T=Q_(397.6, "degK"),
                 fluid={
@@ -547,19 +562,19 @@ def back_to_back():
             casing_temperature=Q_(23.895, "degC"),
             ambient_temperature=Q_(0, "degC"),
         ),
-        Point2Sec(
+        PointFirstSection(
             flow_m=Q_(3.888, "kg/s"),
             speed=Q_(9071, "RPM"),
             b=Q_(10.5, "mm"),
             D=Q_(365, "mm"),
-            suc=State.define(
+            suc=State(
                 p=Q_(5.16, "bar"),
                 T=Q_(300.4, "degK"),
                 fluid={
                     "carbon dioxide": 1,
                 },
             ),
-            disch=State.define(
+            disch=State(
                 p=Q_(15.07, "bar"),
                 T=Q_(400.2, "degK"),
                 fluid={
@@ -585,19 +600,19 @@ def back_to_back():
             casing_temperature=Q_(23.895, "degC"),
             ambient_temperature=Q_(0, "degC"),
         ),
-        Point2Sec(
+        PointFirstSection(
             flow_m=Q_(3.277, "kg/s"),
             speed=Q_(9123, "RPM"),
             b=Q_(10.5, "mm"),
             D=Q_(365, "mm"),
-            suc=State.define(
+            suc=State(
                 p=Q_(5.038, "bar"),
                 T=Q_(300.9, "degK"),
                 fluid={
                     "carbon dioxide": 1,
                 },
             ),
-            disch=State.define(
+            disch=State(
                 p=Q_(15.04, "bar"),
                 T=Q_(404.3, "degK"),
                 fluid={
@@ -626,19 +641,19 @@ def back_to_back():
     ]
 
     test_points_sec2 = [
-        Point1Sec(
+        PointSecondSection(
             flow_m=Q_(4.927, "kg/s"),
             speed=Q_(7739, "RPM"),
             b=Q_(6.38, "mm"),
             D=Q_(320, "mm"),
-            suc=State.define(
+            suc=State(
                 p=Q_(13.11, "bar"),
                 T=Q_(305.1, "degK"),
                 fluid={
                     "carbon dioxide": 1,
                 },
             ),
-            disch=State.define(
+            disch=State(
                 p=Q_(16.31, "bar"),
                 T=Q_(335.1, "degK"),
                 fluid={
@@ -651,19 +666,19 @@ def back_to_back():
             casing_temperature=Q_(17.97, "degC"),
             ambient_temperature=Q_(0, "degC"),
         ),
-        Point1Sec(
+        PointSecondSection(
             flow_m=Q_(4.105, "kg/s"),
             speed=Q_(7330, "RPM"),
             b=Q_(6.38, "mm"),
             D=Q_(320, "mm"),
-            suc=State.define(
+            suc=State(
                 p=Q_(12.69, "bar"),
                 T=Q_(304.5, "degK"),
                 fluid={
                     "carbon dioxide": 1,
                 },
             ),
-            disch=State.define(
+            disch=State(
                 p=Q_(16.78, "bar"),
                 T=Q_(333.3, "degK"),
                 fluid={
@@ -676,19 +691,19 @@ def back_to_back():
             casing_temperature=Q_(17.97, "degC"),
             ambient_temperature=Q_(0, "degC"),
         ),
-        Point1Sec(
+        PointSecondSection(
             flow_m=Q_(3.36, "kg/s"),
             speed=Q_(7412, "RPM"),
             b=Q_(6.38, "mm"),
             D=Q_(320, "mm"),
-            suc=State.define(
+            suc=State(
                 p=Q_(12.62, "bar"),
                 T=Q_(304.4, "degK"),
                 fluid={
                     "carbon dioxide": 1,
                 },
             ),
-            disch=State.define(
+            disch=State(
                 p=Q_(18.15, "bar"),
                 T=Q_(339.9, "degK"),
                 fluid={
@@ -701,19 +716,19 @@ def back_to_back():
             casing_temperature=Q_(17.97, "degC"),
             ambient_temperature=Q_(0, "degC"),
         ),
-        Point1Sec(
+        PointSecondSection(
             flow_m=Q_(2.587, "kg/s"),
             speed=Q_(7449, "RPM"),
             b=Q_(6.38, "mm"),
             D=Q_(320, "mm"),
-            suc=State.define(
+            suc=State(
                 p=Q_(12.46, "bar"),
                 T=Q_(304.5, "degK"),
                 fluid={
                     "carbon dioxide": 1,
                 },
             ),
-            disch=State.define(
+            disch=State(
                 p=Q_(18.6, "bar"),
                 T=Q_(344.1, "degK"),
                 fluid={
@@ -726,19 +741,19 @@ def back_to_back():
             casing_temperature=Q_(17.97, "degC"),
             ambient_temperature=Q_(0, "degC"),
         ),
-        Point1Sec(
+        PointSecondSection(
             flow_m=Q_(2.075, "kg/s"),
             speed=Q_(7399, "RPM"),
             b=Q_(6.38, "mm"),
             D=Q_(320, "mm"),
-            suc=State.define(
+            suc=State(
                 p=Q_(12.52, "bar"),
                 T=Q_(304.5, "degK"),
                 fluid={
                     "carbon dioxide": 1,
                 },
             ),
-            disch=State.define(
+            disch=State(
                 p=Q_(18.88, "bar"),
                 T=Q_(346.4, "degK"),
                 fluid={
@@ -753,7 +768,7 @@ def back_to_back():
         ),
     ]
 
-    compressor = BackToBack(
+    compressor_kwargs = dict(
         guarantee_point_sec1=guarantee_point_sec1,
         guarantee_point_sec2=guarantee_point_sec2,
         test_points_sec1=test_points_sec1,
@@ -761,10 +776,11 @@ def back_to_back():
         speed=Q_(12152.45187, "RPM"),
     )
 
-    return compressor
+    return compressor_kwargs
 
 
 def test_back_to_back(back_to_back):
+    back_to_back = BackToBack(**back_to_back)
     # check flows for first point sec1
     p0f = back_to_back.points_flange_t_sec1[0]
     assert_allclose(p0f.end_seal_flow_m, Q_(386.62, "kg/h").to("kg/s"), rtol=1e-5)
@@ -822,28 +838,28 @@ def test_back_to_back(back_to_back):
     # rotor specified sec2
     p0r = back_to_back.points_rotor_sp_sec2[0]
     assert_allclose(p0r.flow_v.to("m³/h"), 1129.74495)
-    assert_allclose(p0r.flow_m, 52.082125, rtol=1e-5)
+    assert_allclose(p0r.flow_m, 52.082125, rtol=1e-4)
     assert_allclose(p0r.suc.T(), 313.15)
-    assert_allclose(p0r.suc.p(), 13350788.401188)
+    assert_allclose(p0r.suc.p(), 13350788.401188, rtol=1e-5)
     assert_allclose(p0r.head, 30603.247711, rtol=1e-6)
     assert_allclose(p0r.eff, 0.47459, rtol=1e-6)
-    assert_allclose(p0r.power, 3358441.494485)
+    assert_allclose(p0r.power, 3358441.494485, rtol=1e-4)
 
     # flange specified sec2
     p0f_sp = back_to_back.points_flange_sp_sec2[0]
-    assert_allclose(p0f_sp.flow_m, 53.092244)
+    assert_allclose(p0f_sp.flow_m, 53.092244, rtol=1e-4)
     assert_allclose(p0f_sp.suc.T(), 313.15)
-    assert_allclose(p0f_sp.suc.p(), 13350788.401188)
+    assert_allclose(p0f_sp.suc.p(), 13350788.401188, rtol=1e-5)
     assert_allclose(p0f_sp.head, 30603.247711, rtol=1e-6)
     assert_allclose(p0f_sp.eff, 0.47459, rtol=1e-6)
-    assert_allclose(p0f_sp.power, 3423577.541135)
+    assert_allclose(p0f_sp.power, 3423577.541135, 1e-4)
 
     # rotor specified sec1
     p0r_sp = back_to_back.points_rotor_sp_sec1[0]
     assert_allclose(p0r_sp.flow_m, Q_(156223.564, "kg/h").to("kg/s"), rtol=1e-3)
     assert_allclose(p0r_sp.suc.T(), 312.76555064737, rtol=1e-3)
     assert_allclose(p0r_sp.suc.p(), 4739000)
-    assert_allclose(p0r_sp.disch.T(), 380.541484)
+    assert_allclose(p0r_sp.disch.T(), 380.541484, rtol=1e-5)
     assert_allclose(p0r_sp.head, 77283.0955755209, rtol=1e-6)
     assert_allclose(p0r_sp.eff, 0.622869673032321, rtol=1e-6)
     assert_allclose(p0r_sp.power, 5384326.21375024, rtol=1e-3)
@@ -853,11 +869,134 @@ def test_back_to_back(back_to_back):
     assert_allclose(p0f_sp.flow_m, Q_(153951.321926329, "kg/h").to("kg/s"), rtol=1e-2)
     assert_allclose(p0f_sp.suc.T(), 313.15, rtol=1e-3)
     assert_allclose(p0f_sp.suc.p(), 4739000)
-    assert_allclose(p0f_sp.disch.T(), 378.811147)
+    assert_allclose(p0f_sp.disch.T(), 378.811147, rtol=1e-5)
     assert_allclose(p0f_sp.head, 77063.137578, rtol=1e-6)
     assert_allclose(p0f_sp.eff, 0.649591, rtol=1e-6)
     assert_allclose(p0f_sp.power, 5077064.78668, rtol=1e-3)
 
+    # imp_sec1 specified
+    p0f_sp = back_to_back.point_sec1(
+        flow_m=Q_(153951.321926329, "kg/h"),
+        speed=back_to_back.speed,
+    )
+    assert_allclose(p0f_sp.flow_m, Q_(153951.321926329, "kg/h").to("kg/s"), rtol=1e-2)
+    assert_allclose(p0f_sp.suc.T(), 313.15, rtol=1e-3)
+    assert_allclose(p0f_sp.suc.p(), 4739000)
+    assert_allclose(p0f_sp.disch.T(), 378.811147, rtol=1e-2)
+    assert_allclose(p0f_sp.head, 77063.137578, rtol=1e-2)
+    assert_allclose(p0f_sp.eff, 0.649591, rtol=1e-2)
+    # power in this case is the 'real' power consumed by the rotor
+    assert_allclose(p0f_sp.power, 5384326.21375024, rtol=1e-3)
+
+    # imp_sec2 specified
+    p0f_sp = back_to_back.point_sec2(
+        flow_m=Q_(53.092244, "kg/s"),
+        speed=back_to_back.speed,
+    )
+    assert_allclose(p0f_sp.flow_m, 53.092244)
+    assert_allclose(p0f_sp.suc.T(), 313.15)
+    assert_allclose(p0f_sp.suc.p(), 13350788.401188, rtol=1e-5)
+    assert_allclose(p0f_sp.head, 30603.247711, rtol=1e-4)
+    assert_allclose(p0f_sp.eff, 0.47459, rtol=1e-4)
+    # power in this case is the 'real' power consumed by the rotor
+    assert_allclose(p0f_sp.power, 3359509.626922, 1e-4)
+
+
+def test_back_to_back_with_reynolds_correction(back_to_back):
+    back_to_back = BackToBack(**back_to_back, reynolds_correction=True)
+    # check flows for first point sec1
+    p0f = back_to_back.points_flange_t_sec1[0]
+    assert_allclose(p0f.end_seal_flow_m, Q_(386.62, "kg/h").to("kg/s"), rtol=1e-5)
+    assert_allclose(p0f.end_seal_downstream_state.T(), 297.02, rtol=1e-4)
+    assert_allclose(p0f.div_wall_flow_m, Q_(884.50, "kg/h").to("kg/s"), rtol=1e-5)
+    assert_allclose(p0f.div_wall_downstream_state.p(), Q_(1.416, "MPa").to("Pa"))
+    assert_allclose(p0f.div_wall_downstream_state.T(), 355.64, rtol=1e-4)
+
+    # flange test sec1
+    p0f = back_to_back.points_flange_t_sec1[0]
+    assert_allclose(p0f.suc.fluid["CO2"], 1)
+    assert_allclose(p0f.volume_ratio, 1.57845097)
+    assert_allclose(p0f.mach, 0.65270166, rtol=1e-6)
+    assert_allclose(p0f.reynolds, 1568657.944014, rtol=1e-6)
+    assert_allclose(p0f.flow_m, Q_(31377.6, "kg/h").to("kg/s"))
+    assert_allclose(p0f.head, 42576.6847, rtol=1e-6)
+    assert_allclose(p0f.casing_heat_loss, 1787.346)
+    assert_allclose(p0f.eff, 0.62769838, rtol=1e-6)
+    assert_allclose(p0f.power, 591204.944665)
+    k_seal = back_to_back.k_end_seal[0]
+    assert_allclose(k_seal, 7.829411e-06)
+
+    # rotor test sec1
+    p0r = back_to_back.points_rotor_t_sec1[0]
+    assert_allclose(p0r.flow_m, Q_(31986.6583, "kg/h").to("kg/s"))
+    assert_allclose(p0r.suc.T(), 298.881396)
+    assert_allclose(p0r.suc.p(), 708300)
+    assert_allclose(p0r.head, 42614.2514, rtol=1e-6)
+    assert_allclose(p0r.casing_heat_loss, 1787.346)
+    assert_allclose(p0r.eff, 0.62286967, rtol=1e-6)
+    assert_allclose(p0r.power, 607888.669)
+
+    # flange test sec2
+    p0f = back_to_back.points_flange_t_sec2[0]
+    assert_allclose(p0f.suc.fluid["CO2"], 1)
+    assert_allclose(p0f.volume_ratio, 1.125059893)
+    assert_allclose(p0f.mach, 0.49393364, rtol=1e-6)
+    assert_allclose(p0f.reynolds, 1303631.450003, rtol=1e-6)
+    assert_allclose(p0f.flow_m, Q_(17737.2, "kg/h").to("kg/s"))
+    assert_allclose(p0f.head, 12411.07461, rtol=1e-6)
+    assert_allclose(p0f.casing_heat_loss, 1344.156)
+    assert_allclose(p0f.eff, 0.474667774, rtol=1e-6)
+    assert_allclose(p0f.power, 128825.608)
+
+    # rotor test sec2
+    p0r = back_to_back.points_rotor_t_sec2[0]
+    assert_allclose(p0r.flow_m, 4.850643)
+    assert_allclose(p0r.suc.T(), 305.1)
+    assert_allclose(p0r.suc.p(), 1311000)
+    assert_allclose(p0r.head, 12411.07461, rtol=1e-6)
+    assert_allclose(p0r.casing_heat_loss, 1344.156)
+    assert_allclose(p0r.eff, 0.47459, rtol=1e-6)
+    assert_allclose(p0r.power, 126849.949491)
+
+    # rotor specified sec2
+    p0r = back_to_back.points_rotor_sp_sec2[0]
+    assert_allclose(p0r.flow_v.to("m³/h"), 1129.74495)
+    assert_allclose(p0r.flow_m, 52.349973, rtol=1e-4)
+    assert_allclose(p0r.suc.T(), 313.15)
+    assert_allclose(p0r.suc.p(), 13413110.609268, rtol=1e-5)
+    assert_allclose(p0r.head, 30836.456326, rtol=1e-6)
+    assert_allclose(p0r.eff, 0.478206, rtol=1e-6)
+    assert_allclose(p0r.power, 3375713.294289, rtol=1e-4)
+
+    # flange specified sec2
+    p0f_sp = back_to_back.points_flange_sp_sec2[0]
+    assert_allclose(p0f_sp.flow_m, 53.360084, rtol=1e-4)
+    assert_allclose(p0f_sp.suc.T(), 313.15)
+    assert_allclose(p0f_sp.suc.p(), 13413110.609268, rtol=1e-5)
+    assert_allclose(p0f_sp.head, 30836.456326, rtol=1e-6)
+    assert_allclose(p0f_sp.eff, 0.478206, rtol=1e-6)
+    assert_allclose(p0f_sp.power, 3440848.856175, 1e-4)
+
+    # rotor specified sec1
+    p0r_sp = back_to_back.points_rotor_sp_sec1[0]
+    assert_allclose(p0r_sp.flow_m, Q_(156223.564, "kg/h").to("kg/s"), rtol=1e-3)
+    assert_allclose(p0r_sp.suc.T(), 312.76555064737, rtol=1e-3)
+    assert_allclose(p0r_sp.suc.p(), 4739000)
+    assert_allclose(p0r_sp.disch.T(), 380.655898, rtol=1e-5)
+    assert_allclose(p0r_sp.head, 77770.015818, rtol=1e-6)
+    assert_allclose(p0r_sp.eff, 0.626794, rtol=1e-6)
+    assert_allclose(p0r_sp.power, 5384326.21375024, rtol=1e-3)
+
+    # flange specified
+    p0f_sp = back_to_back.points_flange_sp_sec1[0]
+    assert_allclose(p0f_sp.flow_m, Q_(153951.321926329, "kg/h").to("kg/s"), rtol=1e-2)
+    assert_allclose(p0f_sp.suc.T(), 313.15, rtol=1e-3)
+    assert_allclose(p0f_sp.suc.p(), 4739000)
+    assert_allclose(p0f_sp.disch.T(), 378.904722, rtol=1e-5)
+    assert_allclose(p0f_sp.head, 77545.81942, rtol=1e-6)
+    assert_allclose(p0f_sp.eff, 0.654042, rtol=1e-6)
+    assert_allclose(p0f_sp.power, 5077064.78668, rtol=1e-3)
+
     # imp_sec1 specified
     p0f_sp = back_to_back.point_sec1(
         flow_m=Q_(153951.321926329, "kg/h"),
@@ -879,8 +1018,19 @@ def test_back_to_back(back_to_back):
     )
     assert_allclose(p0f_sp.flow_m, 53.092244)
     assert_allclose(p0f_sp.suc.T(), 313.15)
-    assert_allclose(p0f_sp.suc.p(), 13350788.401188)
-    assert_allclose(p0f_sp.head, 30603.247711, rtol=1e-6)
-    assert_allclose(p0f_sp.eff, 0.47459, rtol=1e-6)
+    assert_allclose(p0f_sp.suc.p(), 13413110.609268, rtol=1e-5)
+    assert_allclose(p0f_sp.head, 31556.381204, rtol=1e-4)
+    assert_allclose(p0f_sp.eff, 0.489115, rtol=1e-4)
     # power in this case is the 'real' power consumed by the rotor
-    assert_allclose(p0r.power, 3358441.494485)
+    assert_allclose(p0r.power, 3375713.294289, 1e-4)
+
+
+@pytest.mark.skip("Not converging for now")
+def test_back_to_back_calculate_speed(back_to_back):
+    back_to_back = BackToBack(**back_to_back, reynolds_correction=True)
+    back_to_back.calculate_speed_to_match_discharge_pressure()
+    point_sp = back_to_back.point_sec2(
+        speed=back_to_back.speed,
+        flow_m=back_to_back.guarantee_point_sec2.flow_m,
+    )
+    assert_allclose(point_sp.disch.p(), back_to_back.guarantee_point_sec2.disch.p())
