@@ -7,7 +7,7 @@ Q_ = ccp.Q_
 
 @pytest.fixture
 def fo0():
-    n2 = ccp.State.define(
+    n2 = ccp.State(
         p=Q_(9.85, "bar"), T=Q_(145, "degC"), fluid={"n2": 1 - 1e-15, "o2": 1e-15}
     )
     qm = Q_(71281, "kg/hr")
