@@ -12,25 +12,13 @@ skip = False  # skip slow tests
 @pytest.fixture
 def suc_0():
     fluid = dict(CarbonDioxide=0.76064, Nitrogen=0.23581, Oxygen=0.00284)
-    return State.define(p=Q_(1.839, "bar"), T=291.5, fluid=fluid)
+    return State(p=Q_(1.839, "bar"), T=291.5, fluid=fluid)
 
 
 @pytest.fixture
 def disch_0():
     fluid = dict(CarbonDioxide=0.76064, Nitrogen=0.23581, Oxygen=0.00284)
-    return State.define(p=Q_(5.902, "bar"), T=405.7, fluid=fluid)
-
-
-def test_raises_no_b_D(suc_0, disch_0):
-    with pytest.raises(ValueError) as ex:
-        Point(suc=suc_0, disch=disch_0, flow_v=1, speed=1)
-        assert "Arguments b and D" in str(ex.value)
-    with pytest.raises(ValueError) as ex:
-        Point(suc=suc_0, disch=disch_0, flow_v=1, speed=1, b=1)
-        assert "Arguments b and D" in str(ex.value)
-    with pytest.raises(ValueError) as ex:
-        Point(suc=suc_0, disch=disch_0, flow_v=1, speed=1, D=1)
-        assert "Arguments b and D" in str(ex.value)
+    return State(p=Q_(5.902, "bar"), T=405.7, fluid=fluid)
 
 
 @pytest.fixture
@@ -346,7 +334,7 @@ def suc_1():
         h2s=0.00017,
         water=0.002,
     )
-    suc_1 = State.define(p=Q_(1.6995, "MPa"), T=311.55, fluid=fluid)
+    suc_1 = State(p=Q_(1.6995, "MPa"), T=311.55, fluid=fluid)
 
     return suc_1
 
@@ -367,7 +355,7 @@ def point_eff_flow_v_head_speed_suc_1(suc_1):
 
 
 def test_converted_from_find_speed(point_eff_flow_v_head_speed_suc_1):
-    suc_2 = State.define(
+    suc_2 = State(
         p=Q_(0.2, "MPa"), T=301.58, fluid={"n2": 1 - 1e-15, "co2": 1e-15}
     )
     point_converted_from_find_speed = Point.convert_from(
@@ -396,13 +384,13 @@ def test_converted_from_find_speed(point_eff_flow_v_head_speed_suc_1):
         rtol=1e-2,
     )
     assert_allclose(point_converted_from_find_speed.volume_ratio_ratio, 1.0)
-    assert_allclose(point_converted_from_find_speed.speed, 1259.934797)
+    assert_allclose(point_converted_from_find_speed.speed, 1259.934797, rtol=1e-5)
     assert_allclose(point_converted_from_find_speed.head, 208933.668804, rtol=1e-2)
     assert_allclose(point_converted_from_find_speed.power, 1101698.5104, rtol=1e-2)
 
 
 def test_converted_from_find_volume_ratio(point_eff_flow_v_head_speed_suc_1):
-    suc_2 = State.define(
+    suc_2 = State(
         p=Q_(0.2, "MPa"), T=301.58, fluid={"n2": 1 - 1e-15, "co2": 1e-15}
     )
     point_converted_from_find_volume_ratio = Point.convert_from(
@@ -445,8 +433,62 @@ def test_converted_from_find_volume_ratio(point_eff_flow_v_head_speed_suc_1):
     )
 
 
+def test_converted_from_find_volume_ratio_with_reynolds_correction(
+    point_eff_flow_v_head_speed_suc_1,
+):
+    suc_2 = State(
+        p=Q_(0.2, "MPa"), T=301.58, fluid={"n2": 1 - 1e-15, "co2": 1e-15}
+    )
+    point_converted_from_find_volume_ratio = Point.convert_from(
+        original_point=point_eff_flow_v_head_speed_suc_1,
+        suc=suc_2,
+        find="volume_ratio",
+        reynolds_correction=True,
+    )
+
+    assert_allclose(
+        point_converted_from_find_volume_ratio.b, point_eff_flow_v_head_speed_suc_1.b
+    )
+    assert_allclose(
+        point_converted_from_find_volume_ratio.D, point_eff_flow_v_head_speed_suc_1.D
+    )
+    print(
+        point_converted_from_find_volume_ratio.eff,
+    )
+    assert_allclose(
+        point_converted_from_find_volume_ratio.eff,
+        0.819619,
+        rtol=1e-4,
+    )
+    assert_allclose(
+        point_converted_from_find_volume_ratio.phi,
+        point_eff_flow_v_head_speed_suc_1.phi,
+        rtol=1e-2,
+    )
+    assert_allclose(
+        point_converted_from_find_volume_ratio.psi,
+        7.838824,
+        rtol=1e-6,
+    )
+    assert_allclose(
+        point_converted_from_find_volume_ratio.volume_ratio, 2.669956, rtol=1e-4
+    )
+    assert_allclose(point_converted_from_find_volume_ratio.speed, 1167.101671)
+    assert_allclose(point_converted_from_find_volume_ratio.head, 179275.0, rtol=1e-2)
+    assert_allclose(
+        point_converted_from_find_volume_ratio.power, 875741.275802, rtol=1e-2
+    )
+    assert_allclose(point_converted_from_find_volume_ratio.phi_ratio, 1.0)
+    assert_allclose(
+        point_converted_from_find_volume_ratio.psi_ratio, 0.991846, rtol=1e-4
+    )
+    assert_allclose(
+        point_converted_from_find_volume_ratio.volume_ratio_ratio, 0.872093, rtol=1e-4
+    )
+
+
 def test_converted_from_find_volume_ratio_mach_plot(point_eff_flow_v_head_speed_suc_1):
-    suc_2 = State.define(
+    suc_2 = State(
         p=Q_(0.2, "MPa"), T=301.58, fluid={"n2": 1 - 1e-15, "co2": 1e-15}
     )
     point_converted_from_find_volume_ratio = Point.convert_from(
@@ -456,13 +498,13 @@ def test_converted_from_find_volume_ratio_mach_plot(point_eff_flow_v_head_speed_
     fig = point_converted_from_find_volume_ratio.plot_mach()
 
     assert_allclose(fig.data[2]["x"], 0.6012691126466259)
-    assert_allclose(fig.data[2]["y"], 0.010087427961824047)
+    assert_allclose(fig.data[2]["y"], 0.010087427961824047, rtol=1e-4)
 
 
 def test_converted_from_find_volume_ratio_reynolds_plot(
     point_eff_flow_v_head_speed_suc_1,
 ):
-    suc_2 = State.define(
+    suc_2 = State(
         p=Q_(0.2, "MPa"), T=301.58, fluid={"n2": 1 - 1e-15, "co2": 1e-15}
     )
     point_converted_from_find_volume_ratio = Point.convert_from(
@@ -472,7 +514,7 @@ def test_converted_from_find_volume_ratio_reynolds_plot(
     fig = point_converted_from_find_volume_ratio.plot_reynolds()
 
     assert_allclose(fig.data[2]["x"], 754805.237322)
-    assert_allclose(fig.data[2]["y"], 0.091114, rtol=1e-5)
+    assert_allclose(fig.data[2]["y"], 0.091114, rtol=1e-4)
 
 
 def test_save_load(point_disch_flow_v_speed_suc):
@@ -499,10 +541,10 @@ def test_global_polytropic_method(suc_0, disch_0):
 
 
 def test_case_sc_at():
-    suc = State.define(
+    suc = State(
         p=Q_("5516000 Pa"), T=Q_("311 K"), fluid={"CO2": 0.70000, "METHANE": 0.30000}
     )
-    disch = State.define(
+    disch = State(
         p=Q_("16547000 Pa"), T=Q_("416 K"), fluid={"CO2": 0.70000, "METHANE": 0.30000}
     )
     assert_allclose(eff_pol_huntington(suc, disch), 0.818206, rtol=1e-6)
@@ -515,7 +557,7 @@ def test_point_casing_heat_loss():
         speed=Q_(7894, "RPM"),
         b=Q_(28.5, "mm"),
         D=Q_(365, "mm"),
-        suc=State.define(
+        suc=State(
             p=Q_(1.826, "bar"),
             T=Q_(296.7, "degK"),
             fluid={
@@ -525,7 +567,7 @@ def test_point_casing_heat_loss():
                 "oxygen": 0.0003,
             },
         ),
-        disch=State.define(
+        disch=State(
             p=Q_(6.142, "bar"),
             T=Q_(392.1, "degK"),
             fluid={
@@ -542,3 +584,37 @@ def test_point_casing_heat_loss():
 
     assert_allclose(p.eff, 0.735723, rtol=1e-6)
     assert_allclose(p.suc.fluid["CO2"], 0.80218)
+
+
+def test_ptc10_c6_sample_calculation():
+    suc_sp = ccp.State(
+        p=Q_(200, "psi"),
+        T=Q_(115, "degF"),
+        fluid={"methane": 20, "ethane": 25, "propane": 50, "n-butane": 5},
+    )
+    suc_t = ccp.State(
+        p=Q_(20, "psi"),
+        T=Q_(100, "degF"),
+        fluid={"r134a": 1},
+    )
+    disch_t = ccp.State(
+        p=Q_(67.5, "psi"),
+        T=Q_(187.4, "degF"),
+        fluid={"r134a": 1},
+    )
+    point_t = ccp.Point(
+        suc=suc_t,
+        disch=disch_t,
+        flow_v=Q_(14137, "ft³/min"),
+        speed=Q_(2245, "RPM"),
+        b=Q_(0.0635, "m"),
+        D=Q_(1.033, "m"),
+    )
+    point_sp = ccp.Point.convert_from(
+        point_t,
+        suc=suc_sp,
+        reynolds_correction=True,
+        speed=Q_(3600, "rpm"),
+        find="volume_ratio",
+    )
+    assert_allclose(point_sp.eff, 0.792242)
