@@ -7,11 +7,25 @@ from numpy.testing import assert_allclose
 
 def test_state_possible_name():
     with pytest.raises(ValueError) as exc:
-        State.define(p=100000, T=300, fluid={"fake_name": 0.5, "fake_name2": 0.5})
+        State(p=100000, T=300, fluid={"fake_name": 0.5, "fake_name2": 0.5})
     assert "Fluid fake_name not available." in str(exc.value)
 
 
+def test_state():
+    with pytest.raises(TypeError) as exc:
+        State(p=100000, T=300)
+    assert "A fluid is required" in str(exc.value)
+
+    state = State(p=100000, T=300, fluid={"Methane": 1 - 1e-15, "Ethane": 1e-15})
+    assert state.p().units == "pascal"
+    assert state.T().units == "kelvin"
+    assert state.p().magnitude == 100000
+    assert state.T().magnitude == 300
+    assert_allclose(state.rhomass(), 0.6442542612980722, rtol=1e-7)
+
+
 def test_state_define():
+    # Test deprecated State.define. Keep this test until State.define is removed.
     with pytest.raises(TypeError) as exc:
         State.define(p=100000, T=300)
     assert "A fluid is required" in str(exc.value)
@@ -26,7 +40,7 @@ def test_state_define():
 
 def test_eos():
     ccp.config.EOS = "REFPROP"
-    state = State.define(p=100000, T=300, fluid={"Methane": 1 - 1e-15, "Ethane": 1e-15})
+    state = State(p=100000, T=300, fluid={"Methane": 1 - 1e-15, "Ethane": 1e-15})
     assert state.p().units == "pascal"
     assert state.T().units == "kelvin"
     assert state.p().magnitude == 100000
@@ -34,7 +48,7 @@ def test_eos():
     assert_allclose(state.rhomass(), 0.6442542612980722, rtol=1e-7)
 
     ccp.config.EOS = "PR"
-    state = State.define(p=100000, T=300, fluid={"Methane": 1 - 1e-15, "Ethane": 1e-15})
+    state = State(p=100000, T=300, fluid={"Methane": 1 - 1e-15, "Ethane": 1e-15})
     assert state.p().units == "pascal"
     assert state.T().units == "kelvin"
     assert state.p().magnitude == 100000
@@ -42,7 +56,7 @@ def test_eos():
     assert_allclose(state.rhomass(), 0.6445687063978816, rtol=1e-7)
 
     ccp.config.EOS = "SRK"
-    state = State.define(p=100000, T=300, fluid={"Methane": 1 - 1e-15, "Ethane": 1e-15})
+    state = State(p=100000, T=300, fluid={"Methane": 1 - 1e-15, "Ethane": 1e-15})
     assert state.p().units == "pascal"
     assert state.T().units == "kelvin"
     assert state.p().magnitude == 100000
@@ -50,7 +64,7 @@ def test_eos():
     assert_allclose(state.rhomass(), 0.6442384800595821, rtol=1e-7)
 
     ccp.config.EOS = "HEOS"
-    state = State.define(p=100000, T=300, fluid={"Methane": 1 - 1e-15, "Ethane": 1e-15})
+    state = State(p=100000, T=300, fluid={"Methane": 1 - 1e-15, "Ethane": 1e-15})
     assert state.p().units == "pascal"
     assert state.T().units == "kelvin"
     assert_allclose(state.p().magnitude, 100000)
@@ -62,18 +76,18 @@ def test_eos():
 
 
 def test_new_binary_pairs():
-    state = State.define(
+    state = State(
         p=100000, T=300, fluid={"r134a": 0.6, "co2": 0.2, "n2": 0.1, "o2": 0.1}
     )
     assert_allclose(state.rho(), 3.076654, rtol=1e-6)
-    state = State.define(
+    state = State(
         p=100000, T=300, fluid={"r1234ze": 0.6, "co2": 0.2, "n2": 0.1, "o2": 0.1}
     )
     assert_allclose(state.rho(), 3.373371, rtol=1e-6)
 
 
 def test_state_define_units():
-    state = State.define(
+    state = State(
         p=Q_(1, "bar"),
         T=Q_(300 - 273.15, "celsius"),
         fluid={"Methane": 1 - 1e-15, "Ethane": 1e-15},
@@ -88,7 +102,7 @@ def test_state_define_units():
 
 
 def test_state_define_units_mix():
-    state = State.define(
+    state = State(
         p=Q_(1, "bar"),
         T=Q_(300 - 273.15, "celsius"),
         fluid={"Methane": 0.5, "Ethane": 0.5},
@@ -125,7 +139,7 @@ def test_state_define_units_mix():
     assert_allclose(state.kT().magnitude, 1.232748, rtol=1e-5)
     assert (
         state.__repr__()
-        == 'State.define(p=Q_("100000 Pa"), T=Q_("300 K"), fluid={"METHANE": 0.50000, "ETHANE": 0.50000})'
+        == 'State(p=Q_("100000 Pa"), T=Q_("300 K"), fluid={"METHANE": 0.50000, "ETHANE": 0.50000})'
     )
 
     state.update(p=200000, T=310)
@@ -137,12 +151,12 @@ def test_state_define_units_mix():
     assert_allclose(state.rho().magnitude, 1.8020813868455758)
     assert (
         state.__repr__()
-        == 'State.define(p=Q_("200000 Pa"), T=Q_("310 K"), fluid={"METHANE": 0.50000, "ETHANE": 0.50000})'
+        == 'State(p=Q_("200000 Pa"), T=Q_("310 K"), fluid={"METHANE": 0.50000, "ETHANE": 0.50000})'
     )
 
 
 def test_state_copy():
-    state = State.define(p=100000, T=300, fluid={"Methane": 1 - 1e-15, "Ethane": 1e-15})
+    state = State(p=100000, T=300, fluid={"Methane": 1 - 1e-15, "Ethane": 1e-15})
     state1 = copy(state)
 
     assert state == state
@@ -150,21 +164,19 @@ def test_state_copy():
 
 
 def test_rho_p_inputs():
-    state = State.define(
+    state = State(
         rho=0.9280595769591103, p=Q_(1, "bar"), fluid={"Methane": 0.5, "Ethane": 0.5}
     )
     assert_allclose(state.T().m, 300)
 
 
 def test_rho_T_inputs():
-    state = State.define(
-        rho=0.9280595769591103, T=300, fluid={"Methane": 0.5, "Ethane": 0.5}
-    )
+    state = State(rho=0.9280595769591103, T=300, fluid={"Methane": 0.5, "Ethane": 0.5})
     assert_allclose(state.p().m, 100000)
 
 
 def test_h_s_inputs():
-    state = State.define(
+    state = State(
         h=755784.43407392, s=4805.332018156618, fluid={"Methane": 0.5, "Ethane": 0.5}
     )
     assert_allclose(state.h().magnitude, 755784.43407392, rtol=1e-5)
@@ -173,7 +185,7 @@ def test_h_s_inputs():
 
 
 def test_h_p_inputs():
-    state = State.define(
+    state = State(
         h=755784.43407392, p=Q_(1, "bar"), fluid={"Methane": 0.5, "Ethane": 0.5}
     )
     assert_allclose(state.h().magnitude, 755784.43407392, rtol=1e-5)
@@ -182,26 +194,24 @@ def test_h_p_inputs():
 
 
 def test_T_s_inputs():
-    state = State.define(
-        T=300, s=4805.332018156618, fluid={"Methane": 0.5, "Ethane": 0.5}
-    )
+    state = State(T=300, s=4805.332018156618, fluid={"Methane": 0.5, "Ethane": 0.5})
     assert_allclose(state.h().magnitude, 755784.43407392, rtol=1e-5)
     assert_allclose(state.s().magnitude, 4805.332018156618, rtol=1e-5)
     assert_allclose(state.rho().magnitude, 0.9280595769591103, rtol=1e-5)
 
 
 def test_equality():
-    state = State.define(p=100000, T=300, fluid={"Methane": 1 - 1e-15, "Ethane": 1e-15})
-    state1 = State.define(p=state.p(), T=state.T(), fluid=state.fluid)
-    state2 = State.define(h=state.h(), s=state.s(), fluid=state.fluid)
+    state = State(p=100000, T=300, fluid={"Methane": 1 - 1e-15, "Ethane": 1e-15})
+    state1 = State(p=state.p(), T=state.T(), fluid=state.fluid)
+    state2 = State(h=state.h(), s=state.s(), fluid=state.fluid)
 
     assert state == state1
     assert state == state2
     assert state1 == state2
 
-    state_mix = State.define(p=100000, T=300, fluid={"Methane": 0.5, "Ethane": 0.5})
-    state1_mix = State.define(p=state_mix.p(), T=state_mix.T(), fluid=state_mix.fluid)
-    state2_mix = State.define(h=state_mix.h(), s=state_mix.s(), fluid=state_mix.fluid)
+    state_mix = State(p=100000, T=300, fluid={"Methane": 0.5, "Ethane": 0.5})
+    state1_mix = State(p=state_mix.p(), T=state_mix.T(), fluid=state_mix.fluid)
+    state2_mix = State(h=state_mix.h(), s=state_mix.s(), fluid=state_mix.fluid)
 
     assert state_mix == state1_mix
     assert state_mix == state2_mix
@@ -233,18 +243,18 @@ def test_mix_composition():
     }
 
     with pytest.raises(ValueError) as exc:
-        State.define(p=Q_(0.804, "kgf/cm**2"), T=Q_(37.4, "degC"), fluid=fluid)
+        State(p=Q_(0.804, "kgf/cm**2"), T=Q_(37.4, "degC"), fluid=fluid)
     assert "You might have repeated" in str(exc.value)
 
 
 def test_pickle():
-    state = State.define(p=100000, T=300, fluid={"Methane": 1 - 1e-15, "Ethane": 1e-15})
+    state = State(p=100000, T=300, fluid={"Methane": 1 - 1e-15, "Ethane": 1e-15})
     assert pickle.loads(pickle.dumps(state)) == state
 
 
 def test_improved_error_message():
     with pytest.raises(ValueError) as exc:
-        ccp.State.define(p=100000, T=20, fluid={"methane": 1 - 1e-15, "ethane": 1e-15})
+        ccp.State(p=100000, T=20, fluid={"methane": 1 - 1e-15, "ethane": 1e-15})
 
     assert (
         "Could not define state with {'T': <Quantity(20, 'kelvin')>, 'p': <Quantity(100000, 'pascal')>} and {'METHANE': 0.999999999999999, 'ETHANE': 9.992007221626409e-16}"
@@ -253,7 +263,7 @@ def test_improved_error_message():
 
 
 def test_normalization():
-    suc0 = ccp.State.define(
+    suc0 = ccp.State(
         p=Q_("5338000 Pa"),
         T=Q_("313.15 K"),
         fluid={
@@ -275,7 +285,7 @@ def test_normalization():
         },
     )
     # same state with different order for fluid names
-    suc1 = ccp.State.define(
+    suc1 = ccp.State(
         p=Q_("5338000 Pa"),
         T=Q_("313.15 K"),
         fluid={
@@ -305,5 +315,5 @@ def test_normalization():
         # is dependent on the list order and will impact in last digits
         assert suc0.fluid[k] == suc1.fluid[k]
 
-        # no negativa values
+        # no negative values
         assert suc0.fluid[k] >= 0.0
